@@ -8,9 +8,10 @@ import pkg_resources
 from cleo import Application
 
 from pollyxt_pipelines.radiosondes.commands import WRFProfileToCSVs
-from pollyxt_pipelines.polly_to_scc.commands import CreateSCCBatch, CreateSCC
+from pollyxt_pipelines.polly_to_scc.commands import CreateSCC
 from pollyxt_pipelines.config import ConfigCommand
-from pollyxt_pipelines.scc_access.commands import DeleteSCC, DownloadFiles, RerunSCC, SearchDownloadSCC, SearchSCC, UploadFiles
+from pollyxt_pipelines.scc_access.commands import DeleteSCC, DownloadFiles, Login, RerunSCC, SearchDownloadSCC, SearchSCC, UploadFiles
+from pollyxt_pipelines.locations.commands import LocationPath, ShowLocations
 
 
 def get_package_version():
@@ -33,14 +34,16 @@ def prepare_cli_application() -> Application:
     application = Application('pollyxt_pipelines', get_package_version())
     application.add(WRFProfileToCSVs())
     application.add(CreateSCC())
-    application.add(CreateSCCBatch())
     application.add(ConfigCommand())
+    application.add(Login())
     application.add(UploadFiles())
     application.add(DownloadFiles())
     application.add(DeleteSCC())
     application.add(RerunSCC())
     application.add(SearchSCC())
     application.add(SearchDownloadSCC())
+    application.add(ShowLocations())
+    application.add(LocationPath())
 
     return application
 
